@@ -3,7 +3,7 @@ package Unexpected;
 use 5.010001;
 use namespace::autoclean;
 use overload '""' => sub { $_[ 0 ]->as_string }, fallback => 1;
-use version; our $VERSION = qv( sprintf '0.27.%d', q$Rev: 1 $ =~ /\d+/gmx );
+use version; our $VERSION = qv( sprintf '0.28.%d', q$Rev: 1 $ =~ /\d+/gmx );
 
 use Moo;
 use Scalar::Util qw( blessed );
@@ -26,6 +26,13 @@ __END__
 
 =encoding utf8
 
+=begin markdown
+
+[![Build Status](https://travis-ci.org/pjfl/p5-unexpected.svg?branch=master)](https://travis-ci.org/pjfl/p5-unexpected)
+[![Coverage Status](https://coveralls.io/repos/pjfl/p5-unexpected/badge.png)](https://coveralls.io/r/pjfl/p5-unexpected)
+
+=end markdown
+
 =head1 Name
 
 Unexpected - Exception class composed from traits
@@ -70,7 +77,7 @@ Unexpected - Exception class composed from traits
 
 =head1 Version
 
-This documents version v0.27.$Rev: 1 $ of L<Unexpected>
+This documents version v0.28.$Rev: 1 $ of L<Unexpected>
 
 =head1 Description
 
